==> Bencher-Scenarios-PerinciCmdLine-0.01.tar.gz: Bencher-Scenarios-PerinciCmdLine-0.01/lib/Bencher/Scenario/PerinciCmdLine/Runtime.pm <==
package Bencher::Scenario::PerinciCmdLine::Runtime;

our $DATE = '2016-01-07'; # DATE
our $VERSION = '0.01'; # VERSION

use 5.010001;
use strict;
use warnings;

use App::GenPericmdCompleterScript qw(gen_perinci_cmdline_completer_script);
use File::Temp qw(tempdir);
use Perinci::CmdLine::Gen qw(gen_pericmd_script);

my $tempdir;

our $scenario = {
    summary => 'Benchmark completion response time, to monitor regression',
    modules => {
    },
    participants => [
    ],
    before_list_participants => sub {
        my %args = @_;

        return if $tempdir;
        my $keep = $ENV{DEBUG_KEEP_TEMPDIR} ? 1:0;
        $tempdir = tempdir(CLEANUP => !$keep);

        my $res;

        my @cmds;

        push @cmds, "hello-inline";
        $res = gen_pericmd_script(
            url => "/Perinci/Examples/Tiny/hello_naked",
            cmdline => "Perinci::CmdLine::Inline",
            output_file => "$tempdir/hello-inline",
        );
        die "Can't create hello-inline: $res->[0] - $res->[1]"
            unless $res->[0] == 200;

        push @cmds, "hello-lite";
        $res = gen_pericmd_script(
            url => "/Perinci/Examples/Tiny/hello_naked",
            cmdline => "Perinci::CmdLine::Lite",
            output_file => "$tempdir/hello-lite",
        );
        die "Can't create hello-lite: $res->[0] - $res->[1]"
            unless $res->[0] == 200;

        # XXX hello-lite-packed

        push @cmds, "hello-classic";
        $res = gen_pericmd_script(
            url => "/Perinci/Examples/Tiny/hello_naked",
            cmdline => "Perinci::CmdLine::Classic",
            output_file => "$tempdir/hello-classic",
        );
        die "Can't create hello-classic: $res->[0] - $res->[1]"
            unless $res->[0] == 200;

        my $sc = $args{scenario};
        my $pp = $sc->{participants};

        splice @$pp, 0;

        for my $cmd (@cmds) {
            push @$pp, {
                type => 'perl_code',
                name => "$cmd help",
                summary => 'Run command --help',
                code => sub {
                    my $out = `$tempdir/$cmd --help`;
                    die "Backtick failed: $?" if $?;
                    $out;
                }
            };
            push @$pp, {
                type => 'perl_code',
                name => "$cmd version",
                summary => 'Run command --version',
                code => sub {
                    my $out = `$tempdir/$cmd --version`;
                    die "Backtick failed: $?" if $?;
                    $out;
                }
            };
            push @$pp, {
                type => 'perl_code',
                name => "$cmd",
                summary => 'Run command',
                code => sub {
                    my $out = `$tempdir/$cmd`;
                    die "Backtick failed: $?" if $?;
                    $out;
                }
            };
        }

        my $i = 0; for (@$pp) { $_->{seq} = $i++ }
    },
    #datasets => [
    #],
};

1;
# ABSTRACT: Benchmark completion response time, to monitor regression

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenario::PerinciCmdLine::Runtime - Benchmark completion response time, to monitor regression

=head1 VERSION

This document describes version 0.01 of Bencher::Scenario::PerinciCmdLine::Runtime (from Perl distribution Bencher-Scenarios-PerinciCmdLine), released on 2016-01-07.

=head1 SYNOPSIS

To run benchmark with default option:

 % bencher -m PerinciCmdLine::Runtime

For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.

=head1 BENCHMARK PARTICIPANTS

=over

=back

=head1 SAMPLE BENCHMARK RESULTS

Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.

Benchmark with default option:

 +-----+-----------------------+------+-----------+---------+---------+
 | seq | name                  | rate | time      | errors  | samples |
 +-----+-----------------------+------+-----------+---------+---------+
 | 8   | hello-classic         | 3.9  | 2.5e+02ms | 0.0019  | 20      |
 | 6   | hello-classic help    | 4    | 2.5e+02ms | 0.00083 | 21      |
 | 7   | hello-classic version | 5.52 | 181ms     | 0.0005  | 20      |
 | 5   | hello-lite            | 20.1 | 49.8ms    | 9.1e-05 | 20      |
 | 3   | hello-lite help       | 22.1 | 45.3ms    | 8.3e-05 | 20      |
 | 4   | hello-lite version    | 28   | 36ms      | 0.00016 | 24      |
 | 2   | hello-inline          | 74.4 | 13.4ms    | 3.1e-05 | 20      |
 | 0   | hello-inline help     | 98   | 10ms      | 4.2e-05 | 20      |
 | 1   | hello-inline version  | 99.9 | 10ms      | 1.1e-05 | 20      |
 +-----+-----------------------+------+-----------+---------+---------+

=head1 DESCRIPTION

Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-PerinciCmdLine>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-PerinciCmdLine>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-PerinciCmdLine>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Bencher-Scenarios-PerinciCmdLine-0.02.tar.gz: Bencher-Scenarios-PerinciCmdLine-0.02/lib/Bencher/Scenario/PerinciCmdLine/Runtime.pm <==
package Bencher::Scenario::PerinciCmdLine::Runtime;

our $DATE = '2016-01-22'; # DATE
our $VERSION = '0.02'; # VERSION

use 5.010001;
use strict;
use warnings;

use App::GenPericmdCompleterScript qw(gen_perinci_cmdline_completer_script);
use File::Temp qw(tempdir);
use Perinci::CmdLine::Gen qw(gen_pericmd_script);

my $tempdir;

our $scenario = {
    summary => 'Benchmark completion response time, to monitor regression',
    modules => {
    },
    participants => [
    ],
    before_list_participants => sub {
        my %args = @_;

        return if $tempdir;
        my $keep = $ENV{DEBUG_KEEP_TEMPDIR} ? 1:0;
        $tempdir = tempdir(CLEANUP => !$keep);

        my $res;

        my @cmds;

        push @cmds, "hello-inline";
        $res = gen_pericmd_script(
            url => "/Perinci/Examples/Tiny/hello_naked",
            cmdline => "Perinci::CmdLine::Inline",
            output_file => "$tempdir/hello-inline",
        );
        die "Can't create hello-inline: $res->[0] - $res->[1]"
            unless $res->[0] == 200;

        push @cmds, "hello-lite";
        $res = gen_pericmd_script(
            url => "/Perinci/Examples/Tiny/hello_naked",
            cmdline => "Perinci::CmdLine::Lite",
            output_file => "$tempdir/hello-lite",
        );
        die "Can't create hello-lite: $res->[0] - $res->[1]"
            unless $res->[0] == 200;

        # XXX hello-lite-packed

        push @cmds, "hello-classic";
        $res = gen_pericmd_script(
            url => "/Perinci/Examples/Tiny/hello_naked",
            cmdline => "Perinci::CmdLine::Classic",
            output_file => "$tempdir/hello-classic",
        );
        die "Can't create hello-classic: $res->[0] - $res->[1]"
            unless $res->[0] == 200;

        my $sc = $args{scenario};
        my $pp = $sc->{participants};

        splice @$pp, 0;

        for my $cmd (@cmds) {
            push @$pp, {
                type => 'perl_code',
                name => "$cmd help",
                summary => 'Run command --help',
                code => sub {
                    my $out = `$tempdir/$cmd --help`;
                    die "Backtick failed: $?" if $?;
                    $out;
                }
            };
            push @$pp, {
                type => 'perl_code',
                name => "$cmd version",
                summary => 'Run command --version',
                code => sub {
                    my $out = `$tempdir/$cmd --version`;
                    die "Backtick failed: $?" if $?;
                    $out;
                }
            };
            push @$pp, {
                type => 'perl_code',
                name => "$cmd",
                summary => 'Run command',
                code => sub {
                    my $out = `$tempdir/$cmd`;
                    die "Backtick failed: $?" if $?;
                    $out;
                }
            };
        }

        my $i = 0; for (@$pp) { $_->{seq} = $i++ }
    },
    #datasets => [
    #],
};

1;
# ABSTRACT: Benchmark completion response time, to monitor regression

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenario::PerinciCmdLine::Runtime - Benchmark completion response time, to monitor regression

=head1 VERSION

This document describes version 0.02 of Bencher::Scenario::PerinciCmdLine::Runtime (from Perl distribution Bencher-Scenarios-PerinciCmdLine), released on 2016-01-22.

=head1 SYNOPSIS

To run benchmark with default option:

 % bencher -m PerinciCmdLine::Runtime

For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.

=head1 BENCHMARK PARTICIPANTS

=over

=back

=head1 SAMPLE BENCHMARK RESULTS

Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.

Benchmark with default options (C<< bencher -m PerinciCmdLine::Runtime >>):

 +-----------------------+-----------+-----------+---------+---------+
 | participant           | rate (/s) | time (ms) | errors  | samples |
 +-----------------------+-----------+-----------+---------+---------+
 | hello-classic         | 3.9       | 2.6e+02   | 0.001   | 20      |
 | hello-classic help    | 4         | 2.5e+02   | 0.00058 | 20      |
 | hello-classic version | 5.4       | 1.9e+02   | 0.00053 | 20      |
 | hello-lite            | 20        | 50        | 0.00015 | 20      |
 | hello-lite help       | 22        | 46        | 8.9e-05 | 20      |
 | hello-lite version    | 28        | 36        | 0.0001  | 20      |
 | hello-inline          | 72        | 14        | 3.8e-05 | 20      |
 | hello-inline version  | 95        | 11        | 2.5e-05 | 20      |
 | hello-inline help     | 97        | 10        | 2.8e-05 | 20      |
 +-----------------------+-----------+-----------+---------+---------+

=head1 DESCRIPTION

Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-PerinciCmdLine>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-PerinciCmdLine>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-PerinciCmdLine>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
